pub struct LocalHomologyTable {
pub nseq: usize,
/* private fields */
}Expand description
Table of pairwise local homology information.
Replaces the C LocalHom **localhomtable (njob x njob linked lists)
with a flat map keyed by sequence pair indices.
Fields
nseq: usizeNumber of sequences.
Implementations
Sourceimpl LocalHomologyTable
impl LocalHomologyTable
pub fn new(nseq: usize) -> Self
Sourcepub fn get(&self, i: usize, j: usize) -> &[HomologyRegion]
pub fn get(&self, i: usize, j: usize) -> &[HomologyRegion]
Get homology regions between sequences i and j.
Sourcepub fn get_mut(&mut self, i: usize, j: usize) -> &mut Vec<HomologyRegion>
pub fn get_mut(&mut self, i: usize, j: usize) -> &mut Vec<HomologyRegion>
Get mutable homology regions between sequences i and j.
Sourcepub fn push(&mut self, i: usize, j: usize, region: HomologyRegion)
pub fn push(&mut self, i: usize, j: usize, region: HomologyRegion)
Add a homology region between sequences i and j.